@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Module::CoreList;
 
-our $VERSION = '5.20200620';
+our $VERSION = '5.20200717';
 our %utilities;
 
 sub utilities {
@@ -1622,6 +1622,13 @@ my %delta = (
         removed => {
         }
     },
+    5.033000 => {
+        delta_from => 5.032,
+        changed => {
+        },
+        removed => {
+        }
+    },
 );
 
 %utilities = Module::CoreList::_undelta(\%delta);
